@@ -23,17 +23,9 @@
 #include "settings.h"
 #include "ui_GeneralOptions.h"
 
-#include <KLocalizedString>
-#include <KTitleWidget>
 #include <KWindowSystem>
 
-#include <QButtonGroup>
 #include <QCheckBox>
-#include <QLineEdit>
-#include <QFormLayout>
-#include <QRadioButton>
-#include <QSpacerItem>
-#include <QTextEdit>
 
 GeneralOptionsPage::GeneralOptionsPage(QWidget *parent)
     : QWidget(parent)
@@ -44,6 +36,9 @@ GeneralOptionsPage::GeneralOptionsPage(QWidget *parent)
     m_ui->runningTitle->setLevel(2);
     m_ui->regionTitle->setLevel(2);
 
+    connect(m_ui->kcfg_copyImageToClipboard, &QCheckBox::stateChanged, this, &GeneralOptionsPage::updateAutomaticActions);
+    connect(m_ui->kcfg_autoSaveImage, &QCheckBox::stateChanged, this, &GeneralOptionsPage::updateAutomaticActions);
+
     //On Wayland  we can't programmatically raise and focus the window so we have to hide the option
     if (KWindowSystem::isPlatformWayland() || qstrcmp(qgetenv("XDG_SESSION_TYPE"), "wayland") == 0) {
        delete m_ui->activateWindowButton;
@@ -51,3 +46,14 @@ GeneralOptionsPage::GeneralOptionsPage(QWidget *parent)
 }
 
 GeneralOptionsPage::~GeneralOptionsPage() = default;
+
+void GeneralOptionsPage::updateAutomaticActions() {
+    if (m_ui->kcfg_copyImageToClipboard->isChecked() && m_ui->kcfg_autoSaveImage->isChecked()) {
+        m_ui->kcfg_copySaveLocation->setCheckState(Qt::CheckState::Unchecked);
+        m_ui->kcfg_copySaveLocation->setCheckable(false);
+        m_ui->kcfg_copySaveLocation->setDisabled(true);
+    } else {
+        m_ui->kcfg_copySaveLocation->setCheckable(true);
+        m_ui->kcfg_copySaveLocation->setEnabled(true);
+    }
+}
